@@ -529,6 +529,11 @@ static int dos_helper(void)
 		_AX = -1;
 	}
         break;
+  case DOS_HELPER_BOOTSECT: {
+      extern void fdkernel_boot_mimic(void);
+      fdkernel_boot_mimic();
+      break;
+    }
   case DOS_HELPER_MBR:
     if (LWORD(eax) == 0xfffe) {
       process_master_boot_record();
@@ -2216,6 +2221,10 @@ void setup_interrupts(void) {
   /* init trapped interrupts called via jump */
   for (i = 0; i < 256; i++) {
     interrupt_function[i] = default_interrupt;
+
+    /* don't overwrite; these have been set during video init */
+    if(i == 0x1f || i == 0x43) continue;
+
     if ((i & 0xf8) == 0x60) { /* user interrupts */
 	/* show also EMS (int0x67) as disabled */
 	SETIVEC(i, 0, 0);
