@@ -1,5 +1,5 @@
 /* 
- * (C) Copyright 1992, ..., 1999 the "DOSEMU-Development-Team".
+ * (C) Copyright 1992, ..., 2000 the "DOSEMU-Development-Team".
  *
  * for details see file COPYING in the DOSEMU distribution
  */
@@ -11,10 +11,6 @@
 #endif
 #include "emu.h"
 #include "priv.h"
-#include "lt-threads.h"
-#ifdef X86_EMULATOR
-#include "cpu-emu.h"
-#endif
 
 #if 0
 #define PRIV_TESTING
@@ -23,39 +19,11 @@
 /* Some handy information to have around */
 static uid_t uid,euid;
 static gid_t gid,egid;
-#ifndef USE_THREADS
 static uid_t cur_uid, cur_euid;
 static gid_t cur_gid, cur_egid;
-#else
-#define cur_uid  (OWN_TCB->uid)
-#define cur_euid (OWN_TCB->euid)
-#define cur_gid  (OWN_TCB->gid)
-#define cur_egid (OWN_TCB->egid)
-#endif
 
 static int skip_priv_setting = 0;
 
-#ifdef __NetBSD__
-/* NOTE: Sorry, but the NetBSD stuff is broken currently,
-         ... John Kohl is the man to help us with this ;-) */
-int internal_priv_on(void)
-{
-    if (seteuid(euid) || setegid(egid)) {
-	error("Cannot enable privs!\n");
-	return (0);
-    }
-    return (1);
-}
-
-int internal_priv_off(void)
-{
-  if (seteuid(getuid()) || setegid(getgid())) {
-    error("Cannot disable privs!\n");
-    return (0);
-  }
-  return (1);
-}
-#endif /* __NetBSD__ */
 
 #ifdef __linux__
 
@@ -169,9 +137,6 @@ int priv_iopl(int pl)
     _priv_off();
   }
   else ret = iopl(pl);
-#ifdef X86_EMULATOR
-  if (config.cpuemu) e_priv_iopl(pl);
-#endif
   return ret;
 }
 
