@@ -1,6 +1,6 @@
 /* 
  * All modifications in this file to the original code are
- * (C) Copyright 1992, ..., 1998 the "DOSEMU-Development-Team".
+ * (C) Copyright 1992, ..., 2000 the "DOSEMU-Development-Team".
  *
  * for details see file COPYING in the DOSEMU distribution
  */
@@ -46,16 +46,13 @@
 #include <sys/stat.h>
 #include <errno.h>
 #ifdef __linux__
-#ifndef __GLIBC__
+#if GLIBC_VERSION_CODE < 1000
 #include <linux/fs.h>
 #else
 #include <limits.h>
 #endif
 #endif
 #include <pwd.h>
-#ifdef __NetBSD__
-#include <sys/syslimits.h>		/* PATH_MAX */
-#endif
 
 #include "config.h"
 #include "emu.h"
@@ -66,6 +63,7 @@
 #include "serial.h"
 #include "ser_defs.h"
 #include "priv.h"
+#include "utilities.h"	/* due to getpwnam */
 
 /* See README.serial file for more information on the com[] structure 
  * The declarations for this is in ../include/serial.h
@@ -290,16 +288,6 @@ static int ser_close(int num)
   return (i);
 }
 
-#ifdef __NetBSD__
-#define IUCLC 0
-#define OLCUC 0
-#define OCRNL ONLCR
-#define ONOCR 0
-#define ONLRET 0
-#define OFILL 0
-#define OFDEL 0
-#define XCASE 0
-#endif
 
 Bit8u
 com_readb(ioport_t port) {
@@ -337,10 +325,10 @@ static void do_ser_init(int num)
   /* The following section sets up default com port, interrupt, base
   ** port address, and device path if they are undefined. The defaults are:
   **
-  **   COM1:   irq = 4    base_port = 0x3F8    device = /dev/cua0
-  **   COM2:   irq = 3    base_port = 0x2F8    device = /dev/cua1
-  **   COM3:   irq = 4    base_port = 0x3E8    device = /dev/cua2
-  **   COM4:   irq = 3    base_port = 0x2E8    device = /dev/cua3
+  **   COM1:   irq = 4    base_port = 0x3F8    device = /dev/ttyS0
+  **   COM2:   irq = 3    base_port = 0x2F8    device = /dev/ttyS1
+  **   COM3:   irq = 4    base_port = 0x3E8    device = /dev/ttyS2
+  **   COM4:   irq = 3    base_port = 0x2E8    device = /dev/ttyS3
   **
   ** If COMx is unspecified, the next unused COMx port number is assigned.
   */
@@ -371,10 +359,10 @@ static void do_ser_init(int num)
 
   if (com[num].dev[0] == 0) {			/* Is the device file undef? */
     switch (com[num].real_comport) {		/* Define it using std devs */
-    case 4:  strcpy(com[num].dev, "/dev/cua3"); break;
-    case 3:  strcpy(com[num].dev, "/dev/cua2"); break;
-    case 2:  strcpy(com[num].dev, "/dev/cua1"); break;
-    default: strcpy(com[num].dev, "/dev/cua0"); break;
+    case 4:  strcpy(com[num].dev, "/dev/ttyS3"); break;
+    case 3:  strcpy(com[num].dev, "/dev/ttyS2"); break;
+    case 2:  strcpy(com[num].dev, "/dev/ttyS1"); break;
+    default: strcpy(com[num].dev, "/dev/ttyS0"); break;
     }
   }
 
