@@ -1,5 +1,5 @@
 /* 
- * (C) Copyright 1992, ..., 1998 the "DOSEMU-Development-Team".
+ * (C) Copyright 1992, ..., 2000 the "DOSEMU-Development-Team".
  *
  * for details see file COPYING in the DOSEMU distribution
  */
@@ -9,12 +9,6 @@
 
 __asm__(".org 0x110000");
 
-#ifdef __NetBSD__
-void __foo__()
-{
-/* just take up enough space to force large address initialization */
-}
-#endif
 
 #ifdef __linux__
 int
