@@ -80,6 +80,10 @@
 /* Needed for DIAMOND define */
 #include "vc.h"
 
+#ifdef USE_SBEMU
+#include "sound.h"
+#endif
+
 #include "dma.h"
 
 /*  */
@@ -193,6 +197,19 @@ void vm86_GP_fault(void)
   LWORD(eip) += (csp-lina);
 
   switch (*csp) {
+  
+       /* interrupt calls after prefix: we go back to vm86 */
+  case 0xcc:    /* int 3       and let it generate an */
+  case 0xcd:    /* int         interrupt (don't advance eip) */
+  case 0xce:    /* into */
+    break;
+  case 0xcf:                   /* iret */
+    if (prefix67) goto op0ferr; /* iretd */
+    break;
+  case 0xf1:                   /* int 1 */
+    LWORD(eip)++; /* emulated "undocumented" instruction */
+    do_int(1);
+    break;
 
   case 0x6c:                    /* insb */
     /* NOTE: ES can't be overwritten; prefixes 66,67 should use esi,edi,ecx
@@ -480,6 +497,7 @@ run_vm86(void)
 	fatalerr = 4;
 	}
 
+freeze_idle:
     handle_signals();
 
     { /* catch user hooks here */
@@ -517,9 +535,38 @@ run_vm86(void)
 	    pic_cli();		/* pic_iflag=0 => enabled */
     }
 #endif /* not USE_NEW_INT */
+
+  if (dosemu_frozen) {
+    static int minpoll = 0;
+    if (!(++minpoll & 7)) usleep(10000);
+    goto freeze_idle;
+  }
 }
 /* @@@ MOVE_END @@@ 49152 */
 
+/*
+ * DANG_BEGIN_FUNCTION loopstep_run_vm86
+ * 
+ * description: 
+ * Here we collect all stuff, that has to be executed within
+ * _one_ pass (step) of a loop containing run_vm86().
+ * DANG_END_FUNCTION
+ */
+void loopstep_run_vm86(void)
+{
+	++pic_vm86_count;
+	run_vm86();
+	serial_run();
+	pic_run();		/* trigger any hardware interrupts
+				 * requested */
+#ifdef USE_INT_QUEUE
+	int_queue_run();
+#endif
+#ifdef USE_SBEMU
+	run_sb(); /* Beat Karcher to this one .. 8-) - AM */
+#endif
+}
+
 
 static int callback_level = 0;
 
@@ -561,8 +608,8 @@ void do_call_back(Bit32u codefarptr)
 
         level = callback_level++;
         while (callback_level > level) {
-		run_vm86();
-		serial_run();
+		if (fatalerr) leavedos(99);
+		loopstep_run_vm86();
         }
 	/* ... and back we are */
 	REG(cs) = oldcs;
