@@ -1,5 +1,5 @@
 /* 
- * (C) Copyright 1992, ..., 1999 the "DOSEMU-Development-Team".
+ * (C) Copyright 1992, ..., 2000 the "DOSEMU-Development-Team".
  *
  * for details see file COPYING in the DOSEMU distribution
  */
@@ -33,17 +33,6 @@
 #include <errno.h>
 #include <malloc.h>
 #include <string.h>
-#ifdef __NetBSD__
-#include <stdio.h>
-#include <termios.h>
-#include <stdlib.h>
-#include <time.h>
-#include <ctype.h>
-#include <sys/times.h>
-#include <sys/time.h>
-#include <sys/types.h>
-#include <sys/times.h>
-#endif
 #include <sys/stat.h>
 #include <sys/ioctl.h>
 #if GLIBC_VERSION_CODE >= 2000
@@ -61,10 +50,6 @@
 #include "shared.h"
 #include "serial.h"
 #include "bitops.h"
-#ifdef X86_EMULATOR
-#include "cpu-emu.h"
-#include "bitops.h"
-#endif
 
 /*
  * maximum number of emulated devices allowed.  floppy, mda, etc...
@@ -132,6 +117,7 @@ void SET_HANDLE_COND(int p, int h)
 /* ---------------------------------------------------------------------- */
 /* PORT TRACING								  */
 
+#if 0
 static long nyb2bin[16] =
 {
 	0x30303030, 0x31303030, 0x30313030, 0x31313030,
@@ -150,6 +136,7 @@ static char *
 
 	return s + 3;
 }
+#endif
 
 #define PORTLOG_MAXBITS		16
 #define PORTLOG_MASK		(~(-1 << PORTLOG_MAXBITS))
@@ -806,9 +793,6 @@ int port_init(void)
 	  port_handler[i].irq = EMU_NO_IRQ;
 	  port_handler[i].fd = -1;
 	}
-#ifdef X86_EMULATOR
-	memset (io_bitmap, 0, sizeof(io_bitmap));
-#endif
 
   /* handle 0 maps to the unmapped IO device handler.  Basically any
      ports which don't map to any other device get mapped to this
@@ -1252,14 +1236,6 @@ set_ioperm(int start, int size, int flag)
 	leave_priv_setting();
 
 	i_printf ("nPORT: set_ioperm [%4x:%2d:%d] returns %d\n",start,size,flag,tmp);
-#ifdef X86_EMULATOR
-	if (config.cpuemu && (tmp==0)) {
-	    int i;
-	    for (i=start; i<(start+size); i++)
-		(flag? set_bit(i,io_bitmap) : clear_bit(i,io_bitmap));
-	    i_printf("ePORT: set_ioperm [%4x:%2d:%d]\n",start,size,flag);
-	}
-#endif
 	return tmp;
 }
 
@@ -1267,7 +1243,3 @@ set_ioperm(int start, int size, int flag)
 /* ====================================================================== */
 
 
-#ifdef __NetBSD__
-#error please use old port code for NetBSD
-#endif				/* __NetBSD__ */
-
