@@ -1,5 +1,5 @@
 /* 
- * (C) Copyright 1992, ..., 1999 the "DOSEMU-Development-Team".
+ * (C) Copyright 1992, ..., 2000 the "DOSEMU-Development-Team".
  *
  * for details see file COPYING in the DOSEMU distribution
  */
@@ -26,7 +26,7 @@
 /* disk file types */
 typedef enum {
   NODISK = -1,
-  IMAGE = 0, HDISK, FLOPPY, PARTITION, MAXIDX_DTYPES,
+  IMAGE = 0, HDISK, FLOPPY, PARTITION, DIR_TYPE, MAXIDX_DTYPES,
   NUM_DTYPES
 } disk_t;
 
@@ -37,7 +37,6 @@ typedef enum {
 #define  DISK_IS_DEXE		1
 #define  DISK_DEXE_RDWR		2
 
-
 struct partition {
   int number;
   int beg_head, beg_sec, beg_cyl;
@@ -65,6 +64,7 @@ struct disk {
   int removeable;		/* not user settable */
   int timeout;			/* seconds between floppy timeouts */
   struct partition part_info;	/* neato partition info */
+  void *fatfs;			/* for FAT file system emulation */
 };
 
 #if 0
@@ -106,6 +106,9 @@ struct image_header {
 
 /* CMOS types for the floppies */
 #define THREE_INCH_FLOPPY   4	/* 3.5 in, 1.44 MB floppy */
+#define THREE_INCH_720KFLOP 3	/* 3.5 in,  720 kB floppy */
+#define THREE_INCH_288MFLOP 5	/* 3.5 in, 2.88 MB floppy */
+#define ATAPI_FLOPPY	   16	/* ATAPI removable floppy */
 #define FIVE_INCH_FLOPPY    2	/* 5.25 in, 1.2 MB floppy */
 #define MAX_FDISKS 4
 #define MAX_HDISKS 16
@@ -154,6 +157,7 @@ void d_nullf(struct disk *);
 
 void image_auto(struct disk *);
 void hdisk_auto(struct disk *);
+void dir_auto(struct disk *);
 
 #define partition_auto	hdisk_auto
 #define floppy_auto	d_nullf
@@ -161,6 +165,7 @@ void hdisk_auto(struct disk *);
 #define image_setup	d_nullf
 #define hdisk_setup	d_nullf
 void partition_setup(struct disk *);
+void dir_setup(struct disk *);
 
 #define floppy_setup	d_nullf
 
