@@ -1,5 +1,5 @@
 /* 
- * (C) Copyright 1992, ..., 1999 the "DOSEMU-Development-Team".
+ * (C) Copyright 1992, ..., 2000 the "DOSEMU-Development-Team".
  *
  * for details see file COPYING in the DOSEMU distribution
  */
@@ -41,9 +41,6 @@ struct int_queue_list_struct {
   struct int_queue_struct int_queue_ptr;
   int int_queue_return_addr;
   u_char in_use;
-#ifdef __NetBSD__
-  struct sigcontext saved_regs;
-#endif
 #ifdef __linux__
   struct vm86_regs saved_regs;
 #endif
@@ -73,4 +70,7 @@ void version_init(void);
 
 extern int can_revector(int i);
 
+extern int redir_state;
+extern void set_int21_revectored(int);
+
 #endif
