@@ -1,5 +1,5 @@
 /* 
- * (C) Copyright 1992, ..., 1998 the "DOSEMU-Development-Team".
+ * (C) Copyright 1992, ..., 2000 the "DOSEMU-Development-Team".
  *
  * for details see file COPYING in the DOSEMU distribution
  */
@@ -121,6 +121,15 @@ extern int port_rep_outw(ioport_t port, Bit16u *dest, int df, Bit32u count);
 extern int port_rep_ind(ioport_t port, Bit32u *dest, int df, Bit32u count);
 extern int port_rep_outd(ioport_t port, Bit32u *dest, int df, Bit32u count);
 
+#if GLIBC_VERSION_CODE >= 2000
+  /* arrgh... we need this because <sys/io.h> in glibc includes asm/io.h :-( */
+  #undef inb			port_inb
+  #undef inw			port_inw
+  #undef ind			port_ind
+  #undef outb			port_outb
+  #undef outw			port_outw
+  #undef outd			port_outd
+#endif
 #define inb			port_inb
 #define inw			port_inw
 #define ind			port_ind
