@@ -1,5 +1,5 @@
 /* 
- * (C) Copyright 1992, ..., 1999 the "DOSEMU-Development-Team".
+ * (C) Copyright 1992, ..., 2000 the "DOSEMU-Development-Team".
  *
  * for details see file COPYING in the DOSEMU distribution
  */
@@ -99,11 +99,6 @@
 #include <string.h> 
 #include <errno.h>
 #include <ctype.h>
-#ifdef __NetBSD__
-#include <a.out.h>
-#define sym_entry nlist
-#define flags n_type
-#endif
 
 #ifdef __linux__
 struct gnu_header {
@@ -167,9 +162,6 @@ int change_aout(char *objfile, int update_symtable)
 #ifdef __linux__
   struct bsd_header bsd; 
   struct gnu_header gnu;
-#endif
-#ifdef __NetBSD__
-  struct exec gnu;
 #endif
   int ret;
   if ( (f = fopen(objfile,"r+")) == 0) {
@@ -191,12 +183,6 @@ int change_aout(char *objfile, int update_symtable)
     fclose(f);
     return -1;
   }
-#endif
-#ifdef __NetBSD__
-  if (fread(&gnu,sizeof(gnu),1,f) != 1) {
-      fclose(f);
-      return -1;
-  }
 #endif
   if (update_symtable && gnu.a_syms) {
     struct sym_entry *b = malloc(gnu.a_syms);
@@ -212,9 +198,6 @@ int change_aout(char *objfile, int update_symtable)
     }
 #ifdef __linux__
     fseek(f,sizeof(gnu)+gnu.a_text,SEEK_SET);
-#endif
-#ifdef __NetBSD__
-    fseek(f,N_SYMOFF(gnu),SEEK_SET);
 #endif
     ret = fwrite(b,gnu.a_syms,1,f);
   }
